Enum linregress::Error [−][src]
#[non_exhaustive]
pub enum Error {
Show 13 variants
InconsistentSlopes(InconsistentSlopes),
NoData,
NoFormula,
InvalidFormula,
InvalidDataColumns,
BothFormulaAndDataColumnsGiven,
ColumnNotInData(String),
ModelColumnNotInData(String),
RegressorRegressandDimensionMismatch(String),
RegressionDataError(String),
ModelFittingError(String),
InconsistentVectors,
InconsistentRegressionModel,
}Expand description
An error that can occur in this crate.
Generally this error corresponds to problems with input data or fitting a regression model.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InconsistentSlopes(InconsistentSlopes)Number of slopes and output names is inconsistent.
Tuple Fields of InconsistentSlopes
Cannot fit model without data.
Cannot fit model without formula or data columns.
Given formula is invalid.
Given data columns are invalid.
You must specify either a formula or data columns.
ColumnNotInData(String)Requested column is not in data. (Column given as String)
Tuple Fields of ColumnNotInData
0: StringModelColumnNotInData(String)A column used in the model is misising from the provided data
Tuple Fields of ModelColumnNotInData
0: StringRegressorRegressandDimensionMismatch(String)Regressor and regressand dimensions do not match. (Column given as String)
Tuple Fields of RegressorRegressandDimensionMismatch
0: StringRegressionDataError(String)Error while processing the regression data. (Details given as String)
Tuple Fields of RegressionDataError
0: StringModelFittingError(String)Error while fitting the model. (Details given as String)
Tuple Fields of ModelFittingError
0: StringThe given vectors have inconsistent lengths
The RegressionModel internal state is inconsistent